==> sqlitestudio-3.0.7.tar.gz: Plugins/CsvImport/CsvImport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Nie można odczytać pliku %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Nie znaleziono danych w pliku %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="167"/>
        <source>Enter the custom separator character.</source>
        <translation>Wprowadź własny znak separatora.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="181"/>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation>Wprowadź wartość, która będzie interpretowana jako NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="194"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>Pliki CSV (*.csv);;Pliki tekstowe (*.txt);;Wszystkie pliki (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (przecinek)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (średnik)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (znak tabulacji)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>  (spacja)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Własny:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Włącz to, jeśli pierwsza linia danych w twoim pliku CSV reprezentuje nazwy kolumn. Nie chcesz, aby nazwy kolumn zostały zaimportowane jako zwykłe dane.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation>Pierwsza linia reprezentuje nazwy kolumn CSV</translation>
    </message>
    <message>
        <source>Skip first row of data</source>
        <translation type="obsolete">Pomiń pierwszy wiersz danych</translation>
    </message>
    <message>
        <source>First row represents column names</source>
        <translation type="obsolete">Pierwszy wiersz reprezentuje nazwy kolumn</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Separator pól:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>NULL values:</source>
        <translation>Wartości NULL:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="95"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Jeśli twoje dane CSV zawierają wartości null, zdefiniuj jak są one reprezentowane w CSV.</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/CsvImport/CsvImport_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Nie można odczytać pliku %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Nie znaleziono danych w pliku %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="163"/>
        <source>Enter the custom separator character.</source>
        <translation>Wprowadź własny znak separatora.</translation>
    </message>
    <message>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation type="obsolete">Wprowadź wartość, która będzie interpretowana jako NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="186"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>Pliki CSV (*.csv);;Pliki tekstowe (*.txt);;Wszystkie pliki (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (przecinek)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (średnik)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (znak tabulacji)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>  (spacja)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Własny:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Włącz to, jeśli pierwsza linia danych w twoim pliku CSV reprezentuje nazwy kolumn. Nie chcesz, aby nazwy kolumn zostały zaimportowane jako zwykłe dane.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation>Pierwsza linia reprezentuje nazwy kolumn CSV</translation>
    </message>
    <message>
        <source>Skip first row of data</source>
        <translation type="obsolete">Pomiń pierwszy wiersz danych</translation>
    </message>
    <message>
        <source>First row represents column names</source>
        <translation type="obsolete">Pierwszy wiersz reprezentuje nazwy kolumn</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Separator pól:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>If enabled, then text value provided on the right will be interpreted as NULL</source>
        <translation>Kiedy włączone, to wartość tekstowa podana z prawej strony będzie interpretowana jako NULL</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="88"/>
        <source>NULL values:</source>
        <translation>Wartości NULL:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="98"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Jeśli twoje dane CSV zawierają wartości null, zdefiniuj jak są one reprezentowane w CSV.</translation>
    </message>
</context>
</TS>
